@@ -16,8 +16,9 @@ use Net::FTP;
 use Pod::Html;
 use XML::Writer;
 use version;
+use Parse::LocalDistribution;
 
-our $VERSION = '0.9903';
+our $VERSION = '0.9904';
 
 sub new {
   my ($class, %opts) = @_;
@@ -214,12 +215,18 @@ sub extract_dist {
         $arc->extract($arc->list_files);
         last EXTRACT;
       };
-      ($tar and $gzip) && do {
+      ($tar and $gzip and $suffix !~ /bz2$/) && do {
         my @args = ($gzip, '-dc', $file, '|', $tar, 'xvf', '-');
         print "@args\n";
         system(@args) == 0 or die "@args failed: $?";
         last EXTRACT;
       };
+      ($tar) && do {
+        my @args = ($tar, 'xvf', $file);
+        print "@args\n";
+        system(@args) == 0 or die "@args failed: $?";
+        last EXTRACT;
+      };
     }
     die "Cannot extract $file";
   }
@@ -559,23 +566,20 @@ sub make_ppd {
   }
 
   my $search = $self->{search};
-  {
-    if ($search->search($name, mode => 'dist')) {
-      my $mods = $search->{dist_results}->{$name}->{mods};
-      if ($mods and (ref($mods) eq 'ARRAY')) {
-        foreach my $mod (@$mods) {
-          my $mod_name = $mod->{mod_name};
-          next unless $mod_name;
-          my $mod_vers = $mod->{mod_vers};
-          if ($] < 5.10) {
-            $mod_name .= '::' unless ($mod_name =~ /::/);
-          }
-          push @{$d->{PROVIDE}}, {NAME => $mod_name, VERSION => $mod_vers};
-        }
-      }
+
+  my $parser = Parse::LocalDistribution->new({ALLOW_DEV_VERSION => 1});
+  my $provides = $parser->parse('.');
+  for my $package (keys %{$provides || {}}) {
+    my $name = $package;
+    if ($] < 5.10 and $name !~ /::/) {
+      $name .= '::';
     }
-    else {
-      $search->search_error(qq{Cannot obtain the modules that '$name' provides});
+    my $version = $provides->{$package}{version};
+    $version = undef if defined $version and $version eq 'undef';
+    if ($version) {
+      push @{$d->{PROVIDE}}, {NAME => $name, VERSION => $version};
+    } else {
+      push @{$d->{PROVIDE}}, {NAME => $name};
     }
   }
   my $mod_ref;
@@ -624,9 +628,9 @@ sub print_ppd {
   # weird hack to eliminate an empty line after the XML declaration
   $writer->startTag('SOFTPKG', NAME => $d->{SOFTPKG}->{NAME}, VERSION => $d->{SOFTPKG}->{VERSION});
   $writer->setDataMode(1);
-  $writer->dataElement(TITLE => $d->{TITLE});
-  $writer->dataElement(ABSTRACT => $d->{ABSTRACT});
-  $writer->dataElement(AUTHOR => $d->{AUTHOR});
+  $writer->dataElement(TITLE => encode_non_ascii_chars($d->{TITLE}));
+  $writer->dataElement(ABSTRACT => encode_non_ascii_chars($d->{ABSTRACT}));
+  $writer->dataElement(AUTHOR => encode_non_ascii_chars($d->{AUTHOR}));
   $writer->startTag('IMPLEMENTATION');
 
   foreach (sort keys %{$d->{DEPENDENCY}}) {
