@@ -6,7 +6,7 @@ use File::Find;
 use Safe;
 use CPAN::Meta::YAML qw(LoadFile);
 
-our $VERSION = '0.9903';
+our $VERSION = '0.9904';
 
 sub new {
   my ($class, %opts) = @_;
@@ -29,8 +29,7 @@ sub meta {
   if ($mb and -d '_build') {
     $self->parse_build();
   }
-  else {
-#    $self->parse_makepl();
+  elsif (!$mb) { # ignore Module::Build::Tiny
     $self->parse_make();
   }
   $self->abstract();
@@ -75,7 +74,7 @@ sub parse_build {
           );
   foreach (keys %r) {
       next unless $r{$_};
-      $self->{info}->{$_} = $r{$_};
+      $self->{info}->{$_} ||= $r{$_};
   }
   return 1;
 }
@@ -102,37 +101,6 @@ sub parse_yaml {
   return 1;
 }
 
-sub parse_makepl {
-  my $self = shift;
-  open(my $fh, '<', 'Makefile.PL') or die "Couldn't open Makefile.PL: $!";
-  my @lines = <$fh>;
-  close $fh;
-  my $makeargs;
-  my $content = join "\n", @lines;
-  $content =~ s!\r!!g;
-  $content =~ m!WriteMakefile(\s*\(.*?\bNAME\b.*?\))\s*;!s;
-  unless ($makeargs = $1) {
-    warn "Couldn't extract WriteMakefile args";
-    return;
-  }
-
-  my $c = new Safe();
-  my %r = $c->reval($makeargs);
-  if ($@) {
-    warn "Eval of Makefile.PL failed: $@";
-    return;
-  }
-  unless ($r{NAME}) {
-    warn "Cannot determine NAME in Makefile.PL";
-    return;
-  }
-  foreach (keys %r) {
-      next unless $r{$_};
-      $self->{info}->{$_} ||= $r{$_};
-  }
-  return 1;
-}
-
 sub parse_make {
   my $self = shift;
   my $flag = 0;
@@ -173,38 +141,11 @@ sub parse_make {
   }
   for (@wanted) {
     next unless $r{$_};
-    $self->{info}->{$_} = $r{$_};
+    $self->{info}->{$_} ||= $r{$_};
   }
   return 1;
 }
 
-sub write_makefile {
-  my $self = shift;
-  my $r;
-  my $cwd = $self->{cwd};
-  my $file = 'Makefile.PL';
- MAKE: {
-    local @ARGV;
-    if (my $makepl_arg = $CPAN::Config->{makepl_arg}) {
-      push @ARGV, (split ' ', $makepl_arg);
-    }
-    unless ($r = do "$cwd/$file") {
-      die "Can't parse $file: $@" if $@;
-      die "Can't do $file: $!" unless defined $r;
-      die "Can't run $file" unless $r;
-    }
-  }
-  my @wanted = qw(NAME DISTNAME ABSTRACT ABSTRACT_FROM AUTHOR 
-                  VERSION VERSION_FROM PREREQ_PM);
-  my %wanted;
-  foreach (@wanted) {
-    next unless defined $r->{$_};
-    $wanted{$_} = $r->{$_};
-  }
-  $self->{info} = $r;
-  return 1;
-}
-
 sub abstract {
   my $self = shift;
   my $info = $self->{info};
